@@ -4,5 +4,6 @@ __author__ = 'yangjian'
 
 """
 
-from ._experiment import Experiment
-from .general import GeneralExperiment
\ No newline at end of file
+from ._experiment import Experiment, ExperimentCallback
+from .general import GeneralExperiment
+from ._callback import ConsoleCallback
